@@ -32,8 +32,6 @@ Here are some examples of :ref:`Goals <goal_definition>`:
    modification, ...
 """
 
-from oslo_config import cfg
-
 import pecan
 from pecan import rest
 import wsme
@@ -49,8 +47,6 @@ from watcher.common import exception
 from watcher.common import policy
 from watcher import objects
 
-CONF = cfg.CONF
-
 
 class Goal(base.APIBase):
     """API representation of a goal.
@@ -174,7 +170,7 @@ class GoalsController(rest.RestController):
         limit = api_utils.validate_limit(limit)
         api_utils.validate_sort_dir(sort_dir)
 
-        sort_db_key = (sort_key if sort_key in objects.Goal.fields.keys()
+        sort_db_key = (sort_key if sort_key in objects.Goal.fields
                        else None)
 
         marker_obj = None
